// A simple player that makes a little fort and hides behind it.
//
// Feel free to use this as a starting point for your own player.
//
// ICPC Challenge
// Sturgill, Baylor University

#include "Const.h"
#include <vector>
#include <math.h>
#include <string>
#include <string.h>
#include <iostream>
#include <cstdlib>

#define idle() cout << "idle" << endl; cerr << "idle" << endl;

using namespace std;

/** Simple representation for a child in the Game. */
struct Child {
  // Location of the child.
  int x, y;

  // True if  the child is standing.
  bool standing;

  // Side the child is on.
  int color;

  // What's the child holding.
  int holding;

  // How many more turns this child is dazed.
  int dazed;
};

// X displacement for each walk direction.
int dispX[] = {
  1,
  0,
  -1,
  0,
};

// Y displacement for each walk direction.
int dispY[] = {
  0,
  1,
  0,
  -1,
};

// Extra constant to mark child locations on the map.

const int GROUND_CHILD = 10;

// Another extra constant to mark spaces we should not pick
// up from.
const int GROUND_TAKEN = 11;

// How big of a fort do we want to try to build.
const int FORT_SIZE = 30;

// Walk direction for each child.
int walkDir[] = {
  1,
  0,
  2,
  3
};

//Threat level
int threat;
// Place to put snowball
int target_x, target_y;
int snow_x, snow_y;

int x_goals[] = {5, 9,  5, 11, 5, 15, 10, 15, 29};
int y_goals[] = {5, 9, 11, 5, 15, 5, 15, 13, 29};

int move_stack[6];

// Current game score, for red and blue
int score[ 2 ];

// Current snow height in each cell.
vector< vector< int > > height( SIZE, vector< int >( SIZE ) );

// Contents of each cell.
vector< vector< int > > ground( SIZE, vector< int >( SIZE ) );

// List of current information about each child.
vector< Child > cList( CCOUNT * 2 );

bool move_permited(int x, int y){
  // If someone already is going there, it's forbidden
  for(int i=0; i < 3; i++){
    if(move_stack[i*2] == x && move_stack[(i*2)+1] == y)
      return false;
  }
  // If there's a tree or our snowman, it's forbidden
  if(ground[x][y] != GROUND_EMPTY)
    return false;
  // If there's someone there and he isn't moving, it's forbidden
  for(int i = 0; i < 4; i ++){
    if(cList[i].x == x && cList[i].y == y && move_stack[i*2] == -1)
      return false;
  }

  return true;
}

bool has_obstacle(int x1, int y1, int x2, int y2){
  int current_x = x1;
  int current_y = y1;
  int dx = x2 - x1;
  int dy = y2 - y1;
  cerr << "Checking obstacle between (" << x1 << "," << y1 << ") and (" << x2 << "," << y2 << "): " << endl;
  if(dx == 0){
    current_y += ((current_y > y2)?(-1):(1));
    while(current_y != y2){
      if(ground[current_x][current_y] == GROUND_TREE ||
	 ground[current_x][current_y] == GROUND_SMR ||
	 ground[current_x][current_y] == GROUND_SMB)
	return true;
      else{
	for(int i = 0; i <= 3; i++){
	  if(cList[i].x == current_x && cList[i].y == current_y)
	    return true;
	}
      }
      current_y += ((current_y > y2)?(-1):(1));
    }
  }
  else if(dy ==0){
    current_x += ((current_x > x2)?(-1):(1));
    while(current_x != x2){
      if(ground[current_x][current_y] == GROUND_TREE ||
	 ground[current_x][current_y] == GROUND_SMR ||
	 ground[current_x][current_y] == GROUND_SMB)
	return true;
      else{
	for(int i = 0; i <= 3; i++){
	  if(cList[i].x == current_x && cList[i].y == current_y)
	    return true;
	}
      }
      current_x += ((current_x > x2)?(-1):(1));
    }
  }
  else if(dy < dx){
    int cumulus = 0;
    cumulus += dy;
    if(cumulus >= dx){
      cumulus -= dx;
      current_y += ((current_y > y2)?(-1):(1));
    }
    else if(cumulus <= -dx){
      cumulus += dx;
      current_y += ((current_y > y2)?(-1):(1));
    }
    current_x += ((current_x > x2)?(-1):(1));
    
    while(current_x != x2){
      
      if(ground[current_x][current_y] == GROUND_TREE ||
	 ground[current_x][current_y] == GROUND_SMR ||
	 ground[current_x][current_y] == GROUND_SMB){
	return true;
      }
      else{
	for(int i = 0; i <= 3; i++){
	  if(cList[i].x == current_x && cList[i].y == current_y)
	    return true;
	}
	
      }
      
      cumulus += dy;
      if(cumulus >= dx){
	cumulus -= dx;
	current_y += ((current_y > y2)?(-1):(1));
      }
      else if(cumulus <= -dx){
	cumulus += dx;
	current_y += ((current_y > y2)?(-1):(1));
	}
      current_x += ((current_x > x2)?(-1):(1));
    }
  }
  else{
    int cumulus = 0;
    cumulus += dx;
    if(cumulus >= dy){
      cumulus -= dy;
      current_x += ((current_x > x2)?(-1):(1));
    }
    else if(cumulus <= -dy){
      cumulus += dy;
      current_x += ((current_x > x2)?(-1):(1));
    }
    current_y += ((current_y > y2)?(-1):(1));
    while(current_y != y2){
      cerr << "(" << current_x << "," << current_y << ")";
      if(ground[current_x][current_y] == GROUND_TREE ||
	 ground[current_x][current_y] == GROUND_SMR ||
	 ground[current_x][current_y] == GROUND_SMB){
	return true;
      }
      else{
	for(int i = 0; i <= 3; i++){
	  if(cList[i].x == current_x && cList[i].y == current_y)
	    return true;
	}
      }
      
      cumulus += dx;
      if(cumulus >= dy){
	cumulus -= dy;
	current_x += ((current_x > x2)?(-1):(1));
      }
      else if(cumulus <= -dy){
	cumulus += dy;
	current_x += ((current_x > x2)?(-1):(1));
      }
      current_y += ((current_y > y2)?(-1):(1));
    }
  }
  
  return false;
}

int attack(int child){
  int i;
  int min_distance = 1000;
  int min_dazed = 1000;
  int target = 0;
  int x_off, y_off;
    if(cList[child].dazed){
    idle();
    return 1;
  }

  // Make Snowman if possible
  for(int i = -1; i <= 1; i++){
    for(int j = -1; j <= 1; j++){
      int taboo = false;
      if((cList[child].x > 0 || i >= 0) && (cList[child].y > 0 || j >= 0)){
	if(ground[cList[child].x + i][cList[child].y + j] == GROUND_LM){
	  if(cList[child].holding == HOLD_S1){
	    for(int k = -1; k <=1; k++){
	      for(int l = -1; l <= 1; l++){
		for(int c = 0; c <= 3; c++){
		  if(cList[c].x == cList[child].x+i+k &&
		     cList[c].y == cList[child].y+j+l)
		    if(c < child && cList[c].holding == HOLD_S1) taboo = true; 
		}
	      }
	    }
	    if(!taboo){
	      drop(child, cList[child].x + i, cList[child].y + j);
	      return 1;
	    }
	  }
	}
	else if(ground[cList[child].x + i][cList[child].y + j] == GROUND_SMB){
	  for(int k = -1; k <=1; k++){
	    for(int l = -1; l <= 1; l++){
	      for(int c = 0; c <= 3; c++){
		if(cList[c].x == cList[child].x+i+k &&
		   cList[c].y == cList[child].y+j+l)
		  if(c < child) taboo = true; 
	      }
	    }
	  }
	  if(!taboo){
	    cout << "pickup " << cList[child].x + i << " " <<  cList[child].y + j << endl;
	    return 1;
	  }
	}
      }
    }
  }

  //Pick dropped snowball if possible
  for(int i = -1; i <= 1; i++){
    for(int j = -1; j <= 1; j++){
      int taboo = false;
      if((cList[child].x > 0 || i >= 0) && (cList[child].y > 0 || j >= 0)){
	  if(cList[child].holding == HOLD_EMPTY ||
	     cList[child].holding == HOLD_S1 ||
	     cList[child].holding == HOLD_S2){
	    if(ground[cList[child].x + i][cList[child].y + j] == GROUND_S){
	      for(int k = -1; k <=1; k++){
		for(int l = -1; l <= 1; l++){
		  for(int c = 0; c <= 3; c++){
		    if(cList[c].x == cList[child].x+i+k &&
		       cList[c].y == cList[child].y+j+l)
		      if(c < child) taboo = true; 
		  }
		}
	      }
	      if(!taboo){
		if(!cList[child].standing)
		  cout << "pickup " << cList[child].x + i << " " <<  cList[child].y + j << endl;
		else
		  crouch(child);
		return 1;
	      }
	    }
	  }
      }
    }
  }
  
  
  // Checking for opponents and selecting target
  for(i = 4; i < 8; i++){
    if(cList[i].x != -1){
      int distance, dazed;
      
      int dx = cList[i].x - cList[child].x;
      dx *= ((dx < 0)? (-1) : (1));
      int dy = cList[i].y - cList[child].y;
      dy *= ((dy < 0)? (-1) : (1));
      distance = dx*dx + dy*dy;
      if(has_obstacle(cList[child].x, cList[child].y, cList[i].x, cList[i].y))
	distance *= 2;
      dazed = cList[i].dazed;
      if(dazed < min_dazed){
	target = i;
	min_dazed = dazed;
	min_distance = distance;
	//x_off = dx;
	//y_off = dy;
	cerr << "Min dazed: " << min_dazed << " " << i << endl;
      }
      else if (dazed == min_dazed && distance < min_distance){
	//cerr << "Closer min dazed: " << i << " " << distance << " x " << min_distance << endl;	
	min_distance = distance;
	target = i;
	  //x_off = dx;
	  //y_off = dy;
      }
    }
  }

  
  
  if(cList[child].holding == HOLD_EMPTY){
    if(cList[target].holding == HOLD_S1 ||
       cList[target].holding == HOLD_S2 ||
       cList[target].holding == HOLD_S3){
      cout << "catch " << cList[target].x << " " << cList[target].y << endl;
      return 1;
    }
  }
  
  
  /*cerr << "-------------------------------------------" << endl;
    cerr << "MEGAZORD IMUNE A RESFRIADO" << endl;
  cerr << "I'm the (" << cList[child].x << "," << cList[child].y << ") children." << endl;
  cerr << "(" << cList[4].x << "," << cList[4].y << ")"
       << "(" << cList[5].x << "," << cList[5].y << ")"
       << "(" << cList[6].x << "," << cList[6].y << ")"
       << "(" << cList[7].x << "," << cList[7].y << ") are enemies." << endl;
  cerr << "But my target is the " << target << endl;
  cerr << "-------------------------------------------" << endl;*/
  
  x_off = cList[target].x - cList[child].x;
  y_off = cList[target].y - cList[child].y;

  if(cList[child].holding == HOLD_P3 || cList[child].holding == HOLD_P2 || 
     cList[child].holding == HOLD_M || cList[child].holding == HOLD_L){
    for(int ox = cList[child].x - 1; ox <= cList[child].x + 1; ox++){
      for(int oy = cList[child].y - 1; oy <= cList[child].y + 1; oy++){
	if((ox >= 0) && (oy >= 0) && ((ox != cList[child].x) || (oy != cList[child].y)) && (ground[ox][oy] == GROUND_EMPTY)){ 
	  drop(child, ox, oy);
	  return 1;
	}
      }
    }
    idle();
    return 0;
  }

  if(cList[target].dazed >= 2 && min_distance > 6){
    move(child, cList[target].x, cList[target].y);
    return 1;
  }
    
  if(min_distance >= 64){
    if(cList[child].holding == HOLD_EMPTY){
      if(cList[child].standing){
	if(has_snow(child))
	  crouch(child);
	else
	  move(child, cList[child].x - x_off, cList[child].y - y_off);
      }
      else{
	if(!pick(child))
	  move(child, cList[child].x - x_off, cList[child].y - y_off); 
      }
    }
    else if(cList[child].holding >= HOLD_P1 && cList[child].holding <= HOLD_P3)
      crunch(child);
    else if(cList[child].holding == HOLD_EMPTY){
      if(!pick(child)){
	 move(child, cList[child].x - x_off, cList[child].y - y_off);
      }
    }
    else
      move(child, cList[target].x, cList[target].y);
  }
  else{
    if(cList[child].holding == HOLD_EMPTY){
      if(cList[child].standing){
	if(has_snow(child))
	  crouch(child);
	else{
	  if(min_distance > 6)
	    move(child, cList[child].x - x_off, cList[child].y - y_off);
	  else
	    idle();
	}
      }
      else{ 
	if(!pick(child)){
	  if(min_distance > 6)
	    move(child, cList[child].x - x_off, cList[child].y - y_off);
	  else
	    idle();
	}
      }
    }
    else if(cList[child].holding >= HOLD_P1 && cList[child].holding <= HOLD_P3)
      crunch(child);
    else{ 
      if(cList[child].standing || min_distance < 32){
	if(has_obstacle(cList[child].x, cList[child].y, cList[child].x + x_off, cList[child].y + y_off)){
	  move(child, cList[child].x + x_off, cList[child].y + y_off);
	}
	else
	  cout << "throw " << (int)((float)cList[child].x + (float)x_off*2.0) << " " << (int)((float)cList[child].y + (float)y_off*2.0) << endl;
      }
      else
	cout << "stand" << endl;
    }
  }
  return 1;
}

int has_snow(int child){
    // See if there's some snow nearby.
  for(int ox = cList[child].x - 1; ox <= cList[child].x + 1; ox++){
    for(int oy = cList[child].y - 1; oy <= cList[child].y + 1; oy++){
      // Is there snow to pick up?  Can we pick it up?  Do we want to?
      if((ox >= 0) && (oy >= 0) && ((ox != cList[child].x) || (oy != cList[child].y)) && (ground[ox][oy] == GROUND_EMPTY) && (height[ox][oy] >= 1)){ 
	return 1;
      }
    }
  }
  
  return 0;
}
  
int pick(int child){
  cerr << "Child " << child << " is getting snow..." << endl;
  int sx = -1, sy = -1;
  if(!cList[child].standing && cList[child].holding != HOLD_P3 ) {
    // See if there's some snow nearby.
    for(int ox = cList[child].x - 1; ox <= cList[child].x + 1; ox++){
      for(int oy = cList[child].y - 1; oy <= cList[child].y + 1; oy++){
	// Is there snow to pick up?  Can we pick it up?  Do we want to?
	if((ox >= 0) && (oy >= 0) && ((ox != cList[child].x) || (oy != cList[child].y)) &&(ground[ox][oy] == GROUND_EMPTY) && (height[ox][oy] >= 1)){ 
	  sx = ox;
	  sy = oy;
	  
	}
	
      }
    }
    
  }
  else{
    return 0;
  }
  
  if(sx == -1 || sy == -1)
    return 0;
  // Pick up snow from the space, and mark it
  // as taken so another one of our children
  // won't try to take it also.
  cerr << "Got snow in (" << sx << ", " << sy << ")" << endl;
  cout << "pickup " << sx << " " << sy << endl;
  ground[ sx ][ sy ] = GROUND_TAKEN;
  return 1;
}



int crunch(int child){
  cerr << "Children " << child << " is crunching snow..." << endl;
  cout << "crush" << endl;
  return 1;
}

int crouch(int child){
  if(cList[child].standing){
    cerr << "Crouching children " << child << " (" << cList[child].standing << ") " << endl;
    cout << "crouch" << endl;
    return 1;
  }
  else
    return 0;
}

int drop(int child, int x, int y){
  cerr << "Children " << child << " is droping snow in (" << x << ", " << y << ")" << endl;
  cout << "drop " << x << " " << y << endl;
  return 1;
}

int move(int child_number, int x, int y){
  int dx, dy;
    
  if(cList[child_number].x != x){ // Determining x slope
    if(cList[child_number].x < x)
	dx = 1;
      else
	dx = -1;
  }
  else
    dx = 0;
  if(cList[child_number].y != y){ // Determining y slope
    if(cList[child_number].y < y)
	dy = 1;
      else
	dy = -1;
  }
  else
    dy = 0;

  if(dx == 0 && dy == 0){ // We are already in the destiny
    return 0;
  }
  
  
  
  // Make Snowman if possible
  for(int i = -1; i <= 1; i++){
    for(int j = -1; j <= 1; j++){
      int taboo = false;
      if((cList[child_number].x > 0 || i >= 0) && (cList[child_number].y > 0 || j >= 0)){
	if(ground[cList[child_number].x + i][cList[child_number].y + j] == GROUND_LM){
	  if(cList[child_number].holding == HOLD_S1){
	    for(int k = -1; k <=1; k++){
	      for(int l = -1; l <= 1; l++){
		for(int c = 0; c <= 3; c++){
		  if(cList[c].x == cList[child_number].x+i+k &&
		     cList[c].y == cList[child_number].y+j+l)
		    if(c < child_number && cList[c].holding == HOLD_S1) taboo = true; 
		}
	      }
	    }
	    if(!taboo){
	      drop(child_number, cList[child_number].x + i, cList[child_number].y + j);
	      return 1;
	    }
	  }
	}
	else if(ground[cList[child_number].x + i][cList[child_number].y + j] == GROUND_SMB){
	  for(int k = -1; k <=1; k++){
	    for(int l = -1; l <= 1; l++){
	      for(int c = 0; c <= 3; c++){
		if(cList[c].x == cList[child_number].x+i+k &&
		   cList[c].y == cList[child_number].y+j+l)
		  if(c < child_number) taboo = true; 
	      }
	    }
	  }
	  if(!taboo){
	    cout << "pickup " << cList[child_number].x + i << " " <<  cList[child_number].y + j << endl;
	    return 1;
	  }
	}
      }
    }
  }

  
  if(!cList[child_number].standing){
    cout << "stand" << endl; 
    return 1;
  }
  else if(ground[cList[child_number].x +dx][cList[child_number].y + dy] == GROUND_EMPTY){ 
    // The best move is available
    if(move_permited(cList[child_number].x +dx, cList[child_number].y + dy)){
      cout << "run " << cList[child_number].x +dx << " " << 
	cList[child_number].y + dy << endl;
      move_stack[child_number*2] = cList[child_number].x +dx;
      move_stack[child_number*2+1] = cList[child_number].y + dy;
    }
    else 
      idle();
    return 1;
  }
  else if(ground[cList[child_number].x +dx][cList[child_number].y] == GROUND_EMPTY){
    if(move_permited(cList[child_number].x +dx, cList[child_number].y)){
      cout << "run " << cList[child_number].x +dx << " " << 
	cList[child_number].y << endl;
      move_stack[child_number*2] = cList[child_number].x +dx;
      move_stack[child_number*2+1] = cList[child_number].y;
    }
    else 
      idle();
    return 1;
  }
  else if(ground[cList[child_number].x][cList[child_number].y+dy] == GROUND_EMPTY){
    if(move_permited(cList[child_number].x, cList[child_number].y + dy)){
      cout << "run " << cList[child_number].x  << " " << 
	cList[child_number].y + dy << endl;
      move_stack[child_number*2] = cList[child_number].x;
      move_stack[child_number*2+1] = cList[child_number].y + dy;
    }
    else 
      idle();
    return 1;
  }
  else{ // Obstacle
    if(cList[child_number].x == x){
      if(cList[child_number].y > y){

	if(move_permited(cList[child_number].x-1, cList[child_number].y - 1)){
	  cout << "run " << cList[child_number].x-1  << " " << 
	    cList[child_number].y -1 << endl;
	  move_stack[child_number*2] = cList[child_number].x-1;
	  move_stack[child_number*2+1] = cList[child_number].y-1;
	}
	else{ 
	  cerr << "0" << endl;
	  idle();
	}
	return 1;
      }
      else{
	if(move_permited(cList[child_number].x+1, cList[child_number].y + 1)){
	  cout << "run " << cList[child_number].x+1  << " " << 
	cList[child_number].y +1 << endl;
	  move_stack[child_number*2] = cList[child_number].x+1;
	  move_stack[child_number*2+1] = cList[child_number].y+1;
	}
	else {
	  if(move_permited(cList[child_number].x-1, cList[child_number].y + 1)){
	    cout << "run " << cList[child_number].x-1  << " " << 
	      cList[child_number].y +1 << endl;
	    move_stack[child_number*2] = cList[child_number].x-1;
	    move_stack[child_number*2+1] = cList[child_number].y+1;
	  }
	  else{
	    cerr << "1" << endl;
	    idle();
	  }
	}
      }
      return 1;
    }
    else{
      if(cList[child_number].x > x){
	if(move_permited(cList[child_number].x-1, cList[child_number].y - 1)){
	  cout << "run " << cList[child_number].x-1  << " " << 
	    cList[child_number].y -1 << endl;
	  move_stack[child_number*2] = cList[child_number].x-1;
	  move_stack[child_number*2+1] = cList[child_number].y-1;
	}
	else{
	  if(move_permited(cList[child_number].x-1, cList[child_number].y + 1)){
	    cout << "run " << cList[child_number].x-1  << " " << 
	      cList[child_number].y +1 << endl;
	    move_stack[child_number*2] = cList[child_number].x-1;
	    move_stack[child_number*2+1] = cList[child_number].y+1;
	  }
	  else{
	    if(move_permited(cList[child_number].x, cList[child_number].y - 1)){
	      cout << "run " << cList[child_number].x  << " " << 
		cList[child_number].y -1 << endl;
	      move_stack[child_number*2] = cList[child_number].x;
	      move_stack[child_number*2+1] = cList[child_number].y-1;
	    }
	    else{
	      if(move_permited(cList[child_number].x, cList[child_number].y + 1)){
		cout << "run " << cList[child_number].x  << " " << 
		  cList[child_number].y +1 << endl;
		move_stack[child_number*2] = cList[child_number].x;
		move_stack[child_number*2+1] = cList[child_number].y+1;
	      }
	      else{
		cerr << "3" << endl;
		idle();
	      }
	    }
	  }
	}
	return 1;
      }
      else{ // We should raise the x value
	if(move_permited(cList[child_number].x+1, cList[child_number].y + 1)){
	  cout << "run " << cList[child_number].x+1  << " " << 
	    cList[child_number].y +1 << endl;
	  move_stack[child_number*2] = cList[child_number].x+1;
	  move_stack[child_number*2+1] = cList[child_number].y+1;
	}
	else{
	  if(move_permited(cList[child_number].x+1, cList[child_number].y - 1)){
	    cout << "run " << cList[child_number].x+1  << " " << 
	      cList[child_number].y -1 << endl;
	    move_stack[child_number*2] = cList[child_number].x+1;
	    move_stack[child_number*2+1] = cList[child_number].y-1;
	  }
	  else{
	    if(move_permited(cList[child_number].x, cList[child_number].y - 1)){
	      cout << "run " << cList[child_number].x  << " " << 
		cList[child_number].y -1 << endl;
	      move_stack[child_number*2] = cList[child_number].x;
	      move_stack[child_number*2+1] = cList[child_number].y-1;
	    }
	    else{
	      if(move_permited(cList[child_number].x, cList[child_number].y + 1)){
		cout << "run " << cList[child_number].x  << " " << 
		  cList[child_number].y +1 << endl;
		move_stack[child_number*2] = cList[child_number].x;
		move_stack[child_number*2+1] = cList[child_number].y+1;
	      }
	      else{
		cerr << "3" << endl;
		idle();
	      }
	    }
	  }
	}
      }
      return 1;
    }
  }
}

int main() {


  int snowmans = 0;
  int turnNum;
  int blue_snowmans;
  cin >> turnNum;
  target_x = x_goals[snowmans];
  target_y = y_goals[snowmans];
  while ( turnNum >= 0 ) {
    for(int i = 0; i < 6; i++)
      move_stack[i] = -1;
    
    threat = 0;
    blue_snowmans = 0;
    // Read the current score.
    cin >> score[ RED ] >> score[ BLUE ];
    
    // Read the state of the field.
    for ( int i = 0; i < SIZE; i++ )
      for ( int j = 0; j < SIZE; j++ ) {
        char a, b;
        cin >> a >> b;
        if ( a != '*' ) {
          height[ i ][ j ] = a - '0';
          ground[ i ][ j ] = b - 'a';
	  if(ground[i][j] == GROUND_SMB){
	    blue_snowmans ++;
	    snow_x = i;
	    snow_y = j;
	  }
        } else {
          height[ i ][ j ] = -1;
          ground[ i ][ j ] = -1;
        }
      }

    string token;
    for ( unsigned i = 0; i < cList.size(); i++ ) {
      cin >> token;
      if ( token == "*" ) {
        // Can't see this child
        cList[ i ].x = -1;
        cList[ i ].y = -1;
      } else {
	threat ++;
        // Can see this child, read the description.
        cList[ i ].x = atoi( token.c_str() );
        cin >> cList[ i ].y;

        // Fill in the child's side.
        cList[ i ].color = i / CCOUNT;

        // Read the child's stanse, what he's holding and how much
        // longer he's dazed.
        char ch;
        cin >> ch;
        cList[ i ].standing = ( ch == 'S' );
        cin >> ch;
        cList[ i ].holding = ( ch - 'a' );
        cin >> cList[ i ].dazed;
      }
    }
    threat -= 4;

    // Mark child locations, so we can walk around them.
    for ( unsigned i = 0; i < cList.size(); i++ ) {
      if ( cList[ i ].x >= 0 ) {
        ground[ cList[ i ].x ][ cList[ i ].y ] = GROUND_CHILD;
      }
    }

    if(threat == 0 && blue_snowmans == 0){ // THREAT LEVEL 0
      cerr << "Turno: " << turnNum << endl;
      if(!move(0, target_x, target_y+1)){
	// Build a big one
	if(cList[0].standing && cList[0].holding != HOLD_P3)
	  crouch(0);
	else if(!cList[0].standing && cList[0].holding != HOLD_P3 &&
	  	cList[0].holding != HOLD_L){
	  pick(0);
	}
	else if(cList[0].holding == HOLD_P3){
	  crunch(0);
	}
	else if(cList[0].holding == HOLD_L && ground[target_x][target_y] == GROUND_EMPTY){
	  drop(0, target_x, target_y);
	}
	else
	  idle();
	
      }
      if(!move(1, target_x-1, target_y)){ // Creating medium ball
	if(cList[1].standing && cList[1].holding != HOLD_P2)
	  crouch(1);
	else if (!cList[1].standing && cList[1].holding != HOLD_P2 &&
		cList[1].holding != HOLD_M){
	  pick(1);
	}
	else if(cList[1].holding == HOLD_P2){
	  crunch(1);
	}
	else if(cList[1].holding == HOLD_M && ground[target_x][target_y] == GROUND_L){
	  drop(1, target_x, target_y);
	}
	else idle();
      }
      if(!move(2, target_x, target_y-1)){ // Creating small ball
	if(cList[2].standing && cList[2].holding != HOLD_P1)
	  crouch(2);
	else if (!cList[2].standing && cList[2].holding != HOLD_P1 &&
		cList[2].holding != HOLD_S1){
	  pick(2);
	}
	else if(cList[2].holding == HOLD_P1){
	  crunch(2);
	}
	else if(cList[2].holding == HOLD_S1 && ground[target_x][target_y] == GROUND_LM){
	  drop(2, target_x, target_y);
	  snowmans ++;
	  target_x = x_goals[snowmans];
	  target_y = y_goals[snowmans];
	}
	else idle();
      }
      if(!move(3, target_x+1, target_y)){ // Creating ammo
	if(ground[cList[3].x][cList[3].y-1] == GROUND_EMPTY){
	  if(cList[3].standing)
	    crouch(3);
	  else if(cList[3].holding != HOLD_P1 && cList[3].holding != HOLD_S1)
	    pick(3);
	  else if(cList[3].holding == HOLD_P1)
	    crunch(3);
	  else if(cList[3].holding == HOLD_S1)
	    drop(3, target_x+1, target_y -1);
	}
	else if(ground[cList[3].x][cList[3].y+1] == GROUND_EMPTY){
	  if(cList[3].standing)
	    crouch(3);
	  else if(cList[3].holding != HOLD_P1 && cList[3].holding != HOLD_S1)
	    pick(3);
	  else if(cList[3].holding == HOLD_P1)
	    crunch(3);
	  else if(cList[3].holding == HOLD_S1)
	    drop(3, target_x+1, target_y +1);
	}
	else idle();
      }

      // Children 0 goal is (sx-1, sy-1)
      //TODO!!!!!!
      cin >> turnNum;
    }
    else if(threat == 0 && blue_snowmans > 0){
      if(!move(0, snow_x, snow_y+1)){
	cout << "pickup " << snow_x << " " << snow_y << endl;
      }
      if(!move(1, snow_x-1, snow_y)){
	cout << "pickup " << snow_x << " " << snow_y << endl;
      }
      if(!move(2, snow_x, snow_y-1)){
	cout << "pickup " << snow_x << " " << snow_y << endl;
      }
      if(!move(3, snow_x+1, snow_y)){
	cout << "pickup " << snow_x << " " << snow_y << endl;
      }
      cin >> turnNum;
    }
    else{
      attack(0);
      attack(1);
      attack(2);
      attack(3);

      /*
      // Choose an action for each child.
      for ( int i = 0; i < CCOUNT; i++ ) {
	// Try up to three times to get a useful move
	int tryCount = 0;
	
	while ( tryCount < 3 &&
		!chooseMove( i ) )
        tryCount++;
	
      // If we can't think of a good move, wait and see if something happens.
	if ( tryCount >= 3 )
	  cout << "idle" << endl;
	  }*/
      
      cin >> turnNum;
    }
  }
}
